@@ -41,8 +41,12 @@
 
 #include <KColorSchemeManager>
 #if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+#if HAVE_TEXTUTILS_HAS_WHATSNEW_SUPPORT
+#include <TextAddonsWidgets/VerifyNewVersionWidget>
+#else
 #include <PimCommon/VerifyNewVersionWidget>
 #endif
+#endif
 #include <QWidget>
 
 using namespace Akregator;
@@ -50,7 +54,7 @@ using namespace Akregator;
 class ActionManagerImpl::NodeSelectVisitor : public TreeNodeVisitor
 {
 public:
-    NodeSelectVisitor(ActionManagerImpl *manager)
+    explicit NodeSelectVisitor(ActionManagerImpl *manager)
         : m_manager(manager)
     {
     }
@@ -113,8 +117,12 @@ public:
     WebEngineViewer::ZoomActionMenu *zoomActionMenu = nullptr;
     QAction *mQuickSearchAction = nullptr;
 #if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+#if HAVE_TEXTUTILS_HAS_WHATSNEW_SUPPORT
+    TextAddonsWidgets::VerifyNewVersionWidget *mVerifyNewVersionWidget = nullptr;
+#else
     PimCommon::VerifyNewVersionWidget *mVerifyNewVersionWidget = nullptr;
 #endif
+#endif
 };
 
 void ActionManagerImpl::slotSettingsChanged()
@@ -163,7 +171,11 @@ ActionManagerImpl::ActionManagerImpl(Part *part, QObject *parent)
     d->actionCollection = part->actionCollection();
     d->shareServiceManager = new PimCommon::ShareServiceUrlManager(this);
 #if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+#if HAVE_TEXTUTILS_HAS_WHATSNEW_SUPPORT
+    d->mVerifyNewVersionWidget = new TextAddonsWidgets::VerifyNewVersionWidget(this);
+#else
     d->mVerifyNewVersionWidget = new PimCommon::VerifyNewVersionWidget(this);
+#endif
 #endif
 
     initPart();
@@ -456,11 +468,15 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
 
 #if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
 #if AKREGATOR_STABLE_VERSION
-    const QString url = QStringLiteral("https://cdn.kde.org/ci-builds/pim/akregator/25.08/windows/");
+    const QString url = QStringLiteral("https://cdn.kde.org/ci-builds/pim/akregator/25.12/windows/");
 #else
     const QString url = QStringLiteral("https://cdn.kde.org/ci-builds/pim/akregator/master/windows/");
 #endif
+#if HAVE_TEXTUTILS_HAS_WHATSNEW_SUPPORT
+    d->mVerifyNewVersionWidget->addOsUrlInfo(TextAddonsWidgets::VerifyNewVersionWidget::OsVersion::Windows, url);
+#else
     d->mVerifyNewVersionWidget->addOsUrlInfo(PimCommon::VerifyNewVersionWidget::OsVersion::Windows, url);
+#endif
     auto verifyNewVersionAction = d->mVerifyNewVersionWidget->verifyNewVersionAction();
     coll->addAction(QStringLiteral("verify_check_version"), verifyNewVersionAction);
 #endif
